// Set 13 -- Using Data in the Array

// The Final Version


// Closing gold prices on one day between Feb 23 and 28 
// from 1975 go 2011
// Source  Kitco.com
int [ ] gold = {  185, 133, 139, 180, 250, 616, 500, 366, 464, 395, 
                  284, 352, 405, 432, 488, 415, 358, 350, 329, 376, 
                  377, 398, 353, 292, 286, 294, 260, 292, 257, 400, 
                  434, 564, 683, 937, 978, 1094, 1401 };
PFont f;

final int FIRST_YEAR = 1975;
final int LAST_YEAR = 2011;

float leftEdge, rightEdge, topEdge, bottomEdge;

int minValue, maxValue;
float mean, median;

void setup( )
{
  size( 1000, 600 );
  f = loadFont( "f.vlw" );
  textFont( f );
  textSize( 12 );
  textAlign(CENTER, CENTER);
  rectMode( CORNERS );
  
  leftEdge = 10;
  rightEdge = width-10;
  topEdge = 20;
  bottomEdge = height-20;

  minValue = min(gold);
  maxValue = max(gold);
  
  mean = computeMean( );
  median = computeMedian( );  
}

void draw( )
{
   testPlots( );
   plotMean( );
   plotMedian( );
   noLoop( ); 
}

void plotMedian( )
{
   float y = map( median, maxValue, minValue, topEdge, bottomEdge); 
   stroke( 0 );
   strokeWeight( 2 );
   line( leftEdge, y, rightEdge, y );  
   fill( 0 );
   text( "Median", leftEdge+20, y-10 );  
}

float computeMedian( )
{
    int [ ] sortedGold = sort( gold );
    int medianIndex = gold.length/2;
    float median = gold[ medianIndex ];
    return median;
}

void plotMean ( )
{
   float y = map( mean, maxValue, minValue, topEdge, bottomEdge); 
   stroke( 0, 0, 255 );
   strokeWeight( 2 );
   line( leftEdge, y, rightEdge, y );  
   fill( 0, 0, 255 );
   text( "Mean", leftEdge+20, y-10 );
}

float computeMean( )
{
   float sum = 0;
   for(int i = 0; i < gold.length; i++)
  {
     sum += gold[i];
  } 
  float mean = sum/gold.length;
  return mean;
}

void testPlots( )
{
  float oldX, oldY;
  oldX = 0;
  oldY = 0;
  
  for ( int i = 0; i < gold.length; i++)
  {
     // compute x, y values for current gold value
     float x = map( i, 0, gold.length, leftEdge, rightEdge);
     float y = map( gold[i], maxValue, minValue, topEdge, bottomEdge);
    
     // draw a point for each value
     stroke( 0, 0, 255 );
     strokeWeight( 4 );
     point( x, y );
     
     // label the points:
     fill( 0 );
     int year = (i + FIRST_YEAR)%100;
     // special case for years 2000 to 2009
     // we have to add a leading zero to the result of the % division
     if ( year < 10 )
     {
       text( "0" + year, x, y-10 );
     }
     else
     {
       text( year, x, y-10 );
     }
     
     // special case for the [0]th year: for years after [0], compare current price to last year's price
     // and color line green for gains and red for losses
     if ( i > 0 )
     {
        // used y values to determine if gold price went up
        if (y < oldY)
        {  // it went up so the line is green
          stroke( 0, 200, 0 );
        }
        else
        {  // it went down so the line is red
           stroke( 255, 0, 0 );
        } 
        strokeWeight( 1 );
        line( oldX, oldY, x, y );
        
     }
     
     // draw a gold bar
     fill( 200, 200, 0 );
     stroke(0);
     strokeWeight( 1 );
     rect( x-5, y, x+5, bottomEdge );
     
     // save current value of x and y for use in the next iteration
     // for drawing the line that connects the points
     oldX = x;
     oldY = y;
  }
  
}



